FallbackCoordinator

Struct FallbackCoordinator 

pub struct FallbackCoordinator { /* private fields */ }
coordinates fallback operations across multiple components with acknowledgement.

this is meant to be used together with crate::task_manager::TaskManager, as it allows triggering a fallback event (via CancellationToken) and waiting until all registered components have completed their cleanup.

in summary, every time we spawn a fallback-relevant task inside the manager, we MUST:

when a fallback trigger arrives to the main status loop, we MUST call [FallbackCoordinator::trigger_and_wait] to wait for all registered components to complete their cleanup before re-initializing them under the new upstream server.

finally, a new FallbackCoordinator must be instantiated for the next fallback cycle.

Implementations

Source

impl FallbackCoordinator

pub fn new() -> Self

pub fn register(&self) -> FallbackHandler

register a component that will participate in fallback coordination returns a FallbackHandler that must be called when the component is done

pub fn token(&self) -> CancellationToken

get the cancellation token that signals fallback

pub async fn trigger_fallback_and_wait(&self)

trigger fallback and wait for all registered components to acknowledge