pub struct FallbackHandler { /* private fields */ }Implementations
Sourceimpl FallbackHandler
Handler for a component that will participate in fallback coordination
impl FallbackHandler
Handler for a component that will participate in fallback coordination
⚠️ Warning: dropping this handler without calling FallbackHandler::done will result in a
panic.