pub enum MinerTelemetryStatus {
Matched,
Unmatched,
DuplicateWorkerName,
FetchFailed,
}Expand description
Status of matching a connected miner to discovered management telemetry.
Variants
Matched
Telemetry was matched to this connected miner.
Unmatched
No discovered miner management interface matched this connection.
DuplicateWorkerName
More than one connected miner used the same worker name, so telemetry was not assigned.
FetchFailed
A matching miner was found, but fetching telemetry from its management interface failed.