Server monitoring types
These types are for monitoring the server (upstream connection). An app typically has one server connection with one or more channels.
Structs
- Server
Extended Channel Info - Information about an extended channel opened with the server
- Server
Info - Information about the server (upstream connection)
- Server
Standard Channel Info - Information about a standard channel opened with the server
- Server
Summary - Aggregate information about the server connection
Traits
- Server
Monitoring - Trait for monitoring the server (upstream connection)