pub struct ServerExtendedChannelInfo {Show 16 fields
pub channel_id: u32,
pub user_identity: String,
pub nominal_hashrate: Option<f32>,
pub target_hex: String,
pub extranonce_prefix_hex: String,
pub full_extranonce_size: usize,
pub rollable_extranonce_size: u16,
pub version_rolling: bool,
pub shares_acknowledged: u32,
pub shares_submitted: u32,
pub shares_rejected: u32,
pub shares_rejected_by_reason: HashMap<String, u32>,
pub acknowledged_work_sum: u64,
pub validated_work_sum: f64,
pub best_diff: f64,
pub blocks_found: u32,
}Expand description
Information about an extended channel opened with the server
Fields
channel_id: u32user_identity: Stringnominal_hashrate: Option<f32>None when vardiff is disabled and hashrate cannot be reliably tracked
target_hex: Stringextranonce_prefix_hex: Stringfull_extranonce_size: usizerollable_extranonce_size: u16version_rolling: boolacknowledged_work_sum: u64Work acknowledged by upstream via SubmitSharesSuccess.new_shares_sum.
validated_work_sum: f64Work locally validated by the client channel.
best_diff: f64blocks_found: u32Trait Implementations
Sourceimpl Clone for ServerExtendedChannelInfo
impl Clone for ServerExtendedChannelInfo
Sourcefn clone(&self) -> ServerExtendedChannelInfo
fn clone(&self) -> ServerExtendedChannelInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServerExtendedChannelInfo
impl ComposeSchema for ServerExtendedChannelInfo
Sourceimpl Debug for ServerExtendedChannelInfo
impl Debug for ServerExtendedChannelInfo
Sourceimpl<'de> Deserialize<'de> for ServerExtendedChannelInfo
impl<'de> Deserialize<'de> for ServerExtendedChannelInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more