pub enum PayoutModeError {
NoPayoutMode(String),
InvalidUserIdentity(String),
InvalidPayoutAddress {
address: String,
error: String,
},
InvalidDonationPercentage(String),
MissingMinerPayout {
user_identity: String,
mode: MissingMinerPayoutMode,
},
}Expand description
Errors produced while parsing a payout mode from a user_identity.
Variants
NoPayoutMode(String)
No payout mode was encoded in user_identity.
InvalidUserIdentity(String)
sri/... was used with an unsupported payout pattern.
InvalidPayoutAddress
A payout address was present but could not be converted into a script.
InvalidDonationPercentage(String)
Donation percentage was not an integer in the supported 1..100 range.
MissingMinerPayout
Payout verification was requested but no miner payout address is present.