pub enum PayoutValidationError {
NoSpendableOutputs,
PayoutMismatch {
address: String,
expected_sats: u64,
expected_percentage: u8,
total_spendable_sats: u64,
actual_sats: u64,
},
CoinbaseTxSuffixTooShort,
DecodeCoinbaseOutputs(String),
}Expand description
Errors produced while verifying coinbase outputs against a payout mode.
Variants
NoSpendableOutputs
The coinbase output set has no spendable outputs.
PayoutMismatch
The miner payout did not match the expected distribution.
Fields
CoinbaseTxSuffixTooShort
NewExtendedMiningJob.coinbase_tx_suffix was too short to contain outputs.
DecodeCoinbaseOutputs(String)
Failed to decode serialized coinbase outputs.