Module server

Module server 

Server monitoring types

These types are for monitoring the server (upstream connection). An app typically has one server connection with one or more channels.

Structs

ServerExtendedChannelInfo
Information about an extended channel opened with the server
ServerInfo
Information about the server (upstream connection)
ServerStandardChannelInfo
Information about a standard channel opened with the server
ServerSummary
Aggregate information about the server connection

Traits

ServerMonitoring
Trait for monitoring the server (upstream connection)