SharedMap

Struct SharedMap 

pub struct SharedMap<K: Eq + Clone + Hash, V>(/* private fields */);
Concurrent map wrapper over DashMap providing ergonomic scoped access.

Implementations

Source

impl<K: Eq + Hash + Clone, V> SharedMap<K, V>

pub fn new() -> Self

Create a new concurrent map.

pub fn with<F, R>(&self, key: &K, f: F) -> Option<R>
where F: FnOnce(&V) -> R,

Read a value for a key using a closure.

Caution: f runs while the entry guard is held. Avoid re-entering this SharedMap from inside the closure.

pub fn with_mut<F, R>(&self, key: &K, f: F) -> Option<R>
where F: FnOnce(&mut V) -> R,

Mutate a value for a key using a closure.

Caution: f runs while the entry guard is held. Avoid re-entering this SharedMap from inside the closure.

pub fn for_each<F, Ret>(&self, f: F)
where F: FnMut(K, &V) -> Ret,

Iterate over all entries immutably.

Caution: f runs while an iterator entry guard is held. Avoid re-entering this SharedMap from inside the closure.

pub fn for_each_mut<F, Ret>(&self, f: F)
where F: FnMut(K, &mut V) -> Ret,

Iterate over all entries mutably.

Caution: f runs while an iterator entry guard is held. Avoid re-entering this SharedMap from inside the closure.

pub fn try_for_each_mut<F, E>(&self, f: F) -> Result<(), E>
where F: FnMut(K, &mut V) -> Result<(), E>,

Fallible mutable iteration over all entries.

Caution: f runs while an iterator entry guard is held. Avoid re-entering this SharedMap from inside the closure.

pub fn try_for_each<F, E>(&self, f: F) -> Result<(), E>
where F: Fn(K, &V) -> Result<(), E>,

Fallible iteration over all entries.

Caution: f runs while an iterator entry guard is held. Avoid re-entering this SharedMap from inside the closure.

pub fn insert(&self, key: K, value: V) -> Option<V>

Insert a key-value pair.

pub fn remove(&self, key: &K) -> Option<(K, V)>

Remove a key.

pub fn contains_key(&self, key: &K) -> bool

Check if a key exists.

pub fn retain<F>(&self, f: F)
where F: FnMut(&K, &mut V) -> bool,

Retain entries matching predicate.

Caution: f runs while DashMap is mutating internal shards. Avoid re-entering this SharedMap from inside the predicate.

pub fn keys(&self) -> Vec<K>
where K: Clone,

Collect all keys.

pub fn len(&self) -> usize

Number of entries.

pub fn is_empty(&self) -> bool

Check if empty.